package org.expressolivre.cte.calendar.compartilhar;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import org.expressolivre.cte.common.BaseCalendarTestCase;
import org.expressolivre.cte.common.Config;
import org.expressolivre.cte.pages.calendar.AppointmentPage;
import org.expressolivre.cte.pages.calendar.CalendarTodayViewPage;
import org.testng.annotations.Optional;
import org.testng.annotations.Parameters;
import org.testng.annotations.Test;

/**
 * Suite:[FUN03.7] Compartilhar agenda
 * 
 * Caso de Teste: EL-985:Adicionar evento à agenda compartilhada com permissão
 * 
 * Link: http://testlink.expressolivre.org/linkto.php?tprojectPrefix=EL&item=
 * testcase&id=EL-985
 * 
 * @author L.F.Estivalet (Serpro)
 * 
 *         Created on Aug 24, 2011 at 2:52:19 PM
 * 
 */
public class AdicionarCompromissoAgendaTestCase extends BaseCalendarTestCase {

	@Parameters({ "owner", "tipo", "titulo", "descricao", "local",
			"dataInicial", "horaInicial", "minutoInicial", "dataFinal",
			"horaFinal", "minutoFinal", "prioridade" })
	@Test
	public void adicionarCompromissoAgendaCompartilhada(String owner,
			@Optional("Normal") String tipo, String titulo,
			@Optional("") String descricao, @Optional("") String local,
			@Optional("") String dataInicial, String horaInicial,
			String minutoInicial, @Optional("") String dataFinal,
			String horaFinal, String minutoFinal,
			@Optional("Normal") String prioridade) throws ParseException {
		CalendarTodayViewPage ctvp = super.openTodayView();

		// Busca o nome do usuario do arquivo de confirguracao.
		String userName = Config.getInstance().getConfig(owner + ".name");
		// Muda dono do compromisso.
		ctvp.setOwner(userName);

		Calendar cal = Calendar.getInstance();
		SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
		SimpleDateFormat sdf2 = new SimpleDateFormat("dd/MM/yyyy");

		// Se a data inicial nao for informada, pega data corrente.
		if ("".equals(dataInicial)) {
			dataInicial = sdf2.format(cal.getTime());
		}

		// Se a data final nao for informada, pega data corrente.
		if ("".equals(dataFinal)) {
			dataFinal = sdf2.format(cal.getTime());
		}

		// Transforma a data inicial informada (dd/MM/yyyy) para (yyyyMMdd)
		Date dtIni = sdf2.parse(dataInicial);

		AppointmentPage ap = super.newAppointment(sdf.format(dtIni));
		ap.setType(tipo);
		ap.setTitle(titulo);
		ap.setDescription(descricao);
		ap.setLocation(local);
		ap.setStartDate(dataInicial);
		ap.setStartHour(horaInicial);
		ap.setStartMinute(minutoInicial);
		ap.setEndDate(dataFinal);
		ap.setEndHour(horaFinal);
		ap.setEndMinute(minutoFinal);
		ap.setPriority(prioridade);
		ap.saveAppointment();
	}

}
