package org.expressolivre.cte.pages.calendar;

import java.util.List;
import java.util.Set;

import org.expressolivre.cte.pages.common.Page;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.PageFactory;
import org.openqa.selenium.support.ui.ExpectedCondition;
import org.openqa.selenium.support.ui.WebDriverWait;

/**
 * @author L.F.Estivalet (Serpro)
 * 
 *         Created on Aug 17, 2011 at 9:16:01 AM
 * 
 */
public class AgendaPermissionPage extends Page {

	/** Permitir acesso para ler compromissos da agenda. */
	@FindBy(id = "user_list")
	private WebElement userList;

	/** Permitir acesso para ler compromissos da agenda. */
	@FindBy(xpath = "//table[@id='tableDivAppbox']/tbody/tr/td/form/center/table/tbody/tr[2]/td[3]/table/tbody/tr[1]/td[1]/input")
	private WebElement read;

	/** Permitir acesso para adicionar compromissos da agenda. */
	@FindBy(xpath = "//table[@id='tableDivAppbox']/tbody/tr/td/form/center/table/tbody/tr[2]/td[3]/table/tbody/tr[2]/td[1]/input")
	private WebElement add;

	/** Permitir acesso para editar compromissos da agenda. */
	@FindBy(xpath = "//table[@id='tableDivAppbox']/tbody/tr/td/form/center/table/tbody/tr[2]/td[3]/table/tbody/tr[3]/td[1]/input")
	private WebElement edit;

	/** Permitir acesso para remover compromissos da agenda. */
	@FindBy(xpath = "//table[@id='tableDivAppbox']/tbody/tr/td/form/center/table/tbody/tr[2]/td[3]/table/tbody/tr[4]/td[1]/input")
	private WebElement remove;

	@FindBy(xpath = "//table[@id='tableDivAppbox']/tbody/tr/td/form/center/table/tbody/tr[2]/td[3]/table/tbody/tr[5]/td[1]/input")
	private WebElement restrict;

	@FindBy(xpath = "//table[@id='tableDivAppbox']/tbody/tr/td/form/center/table/tbody/tr[4]/td[2]/center/input[1]")
	private WebElement okButton;

	@FindBy(xpath = "//table[@id='tableDivAppbox']/tbody/tr/td/form/center/table/tbody/tr[4]/td[2]/center/input[2]")
	private WebElement addButton;

	@FindBy(xpath = "//table[@id='tableDivAppbox']/tbody/tr/td/form/center/table/tbody/tr[4]/td[2]/center/input[3]")
	private WebElement removeButton;

	@FindBy(xpath = "//table[@id='tableDivAppbox']/tbody/tr/td/form/center/table/tbody/tr[4]/td[2]/center/input[4]")
	private WebElement cancelButton;

	public AgendaPermissionPage(WebDriver driver) {
		super(driver);
		// TODO Auto-generated constructor stub
	}

	/**
	 * Verifica se o usuario ja esta na lista de permissoes.
	 * 
	 * @param userName
	 * @return
	 */
	public Boolean isUserInList(String userName) {
		return super.isValueInCombo(this.userList, userName, true);
	}

	/**
	 * Remove todos os usuarios do compartilhamento.
	 */
	public void removeAllUsers() {
		List<WebElement> users = super.getComboElements(this.userList);
		for (WebElement user : users) {
			user.setSelected();
			this.removeButton.click();
		}
	}

	/**
	 * Adaptacao da solucao para lidar com janelas popups obtida em <a
	 * href="http://groups.google.com/group
	 * /webdriver/browse_thread/thread/038a911803f26dcd">link</a>
	 * 
	 * @return
	 */
	public AgendaAddACLUserPage addUserACL() {
		// Get current windows
		final Set<String> beforeHandles = driver.getWindowHandles();
		// click action that cause new window to open
		this.addButton.click();
		// wait for the new window to open
		new WebDriverWait(driver, 30) {
		}.until(new ExpectedCondition<Boolean>() {
			public Boolean apply(WebDriver driver) {
				return (driver.getWindowHandles().size() > beforeHandles.size()) ? true
						: false;
			}
		});

		// Get after handles
		Set<String> afterHandles = driver.getWindowHandles();
		// remove all before handles from after. Leaves you with new window
		// handle
		afterHandles.removeAll(beforeHandles);
		// Switch to the new window
		String newWindowHandle = afterHandles.iterator().next();
		driver.switchTo().window(newWindowHandle);

		return PageFactory.initElements(driver, AgendaAddACLUserPage.class);
	}

	public void setReadPermission(boolean read) {
		if (read && !this.read.isSelected()) {
			this.read.click();
		} else if (!read && this.read.isSelected()) {
			this.read.click();
		}
	}

	public void setEditPermission(boolean edit) {
		if (edit && !this.edit.isSelected()) {
			this.edit.click();
		} else if (!edit && this.edit.isSelected()) {
			this.edit.click();
		}
	}

	public void setAddPermission(boolean add) {
		if (add && !this.add.isSelected()) {
			this.add.click();
		} else if (!add && this.add.isSelected()) {
			this.add.click();
		}
	}

	public void setRemovePermission(boolean remove) {
		if (remove && !this.remove.isSelected()) {
			this.remove.click();
		} else if (!remove && this.remove.isSelected()) {
			this.remove.click();
		}
	}

	public void setRestrictPermission(boolean restrict) {
		if (restrict && !this.restrict.isSelected()) {
			this.restrict.click();
		} else if (!restrict && this.restrict.isSelected()) {
			this.restrict.click();
		}
	}

	public void clearPemissions() {
		this.setReadPermission(false);
		this.setEditPermission(false);
		this.setRemovePermission(false);
		this.setAddPermission(false);
		this.setRestrictPermission(false);
	}

	public void cancel() {
		this.cancelButton.click();
	}

	public void apply() {
		this.okButton.click();
	}
}
