package org.expressolivre.cte.pages.calendar;

import java.util.List;

import org.expressolivre.cte.pages.common.Page;
import org.openqa.selenium.Alert;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.PageFactory;
import org.testng.Assert;

/**
 * @author L.F.Estivalet (Serpro)
 * 
 *         Created on Jul 25, 2011 at 2:25:28 PM
 * 
 */
public class AppointmentViewPage extends Page {

	public static final String DESCRIPTION = "Descrição:";
	public static final String LOCAL = "Localização:";
	public static final String START = "Início Data/hora:";
	public static final String END = "Data/Hora de término:";
	public static final String PRIORITY = "Prioridade:";
	public static final String ACCESS = "Acesso:";
	public static final String PARTICIPANTS = "Participantes:";
	public static final String CREATED_BY = "Criado por:";
	public static final String UPDATED = "Atualizado:";
	public static final String LAST_UPDATED_BY = "Última alteração realizada por:";
	public static final String ATTACHMENTS = "Anexos:";

	/** Botao para editar um compromisso. */
	@FindBy(xpath = "//table[@id='calendar_viewevent_button_left']/tbody/tr/td[1]/nobr/form/div/input[@id='']")
	private WebElement editButton;

	/** Botao para editar serie de compromissos. */
	@FindBy(xpath = "//table[@id='calendar_viewevent_button_left']/tbody/tr/td[2]/nobr/form/div/input[@id='']")
	private WebElement editSeriesButton;

	@FindBy(xpath = "//table[@id='calendar_viewevent_button_left']/tbody/tr/td[2]/nobr/form/div/input[@id='']")
	private WebElement readyButton;

	@FindBy(xpath = "//table[@id='calendar_viewevent_button_right']/tbody/tr/td/nobr/form/div/input[@id='']")
	private WebElement removeButton;

	@FindBy(xpath = "//table[@id='calendar_viewevent_button_right']/tbody/tr/td[2]/nobr/form/div/input[@id='']")
	private WebElement removeSeriesButton;

	@FindBy(xpath = "//table[@id='calendar_view_event']/tbody/tr[1]/td[2]")
	private WebElement title;

	public AppointmentViewPage(WebDriver driver) {
		super(driver);
		// TODO Auto-generated constructor stub
	}

	/**
	 * Edita o compromisso previamente selecionado.
	 * 
	 * @return Retorna pagina de edicao do compromisso.
	 */
	public AppointmentEditPage editAppointment() {
		this.editButton.click();
		return PageFactory.initElements(driver, AppointmentEditPage.class);

	}

	/**
	 * Edita a serie de compromissos previamente selecionado.
	 * 
	 * @return Retorna pagina de edicao do compromisso.
	 */
	public AppointmentEditPage editAppointmentSeries() {
		this.editSeriesButton.click();
		return PageFactory.initElements(driver, AppointmentEditPage.class);

	}

	/**
	 * Remove um compromisso.
	 */
	public void removeAppointment() {
		this.removeButton.click();
		this.removeAlert();
	}

	/**
	 * 
	 */
	public void ready() {
		this.readyButton.click();
	}

	/**
	 * Remove a serie de compromissos.
	 */
	public void removeSeriesAppointment() {
		this.removeSeriesButton.click();
		this.removeAlert();
	}

	/**
	 * Exibe alerta ao tentar remover um compromisso.
	 */
	private void removeAlert() {
		Alert alert = driver.switchTo().alert();
		Assert.assertEquals(
				alert.getText(),
				"Tem certeza que deseja remover esta entrada?\nIsto irá remover esta entrada para todos usuários.");
		alert.accept();
	}

	/**
	 * @return the title
	 */
	public String getTitle() {
		return title.getText();
	}

	/**
	 * Percorre a tabela em busca da informacao desejada.
	 * 
	 * @param label
	 *            Informa o label procurado. Ex: "Descrição".
	 * @return Retorna o valor correspondente ao label encontrado. Se label nao
	 *         for encontrado retorna <code>null</code>.
	 */
	public String getAppointmentInfo(String label) {
		List<WebElement> rows = driver.findElements(By
				.xpath("//table[@id='calendar_view_event']/tbody/tr"));
		// Comeca a partir da linha 2 pois a linha eh sempre o titulo do
		// compromisso.
		for (int i = 2; i <= rows.size(); i++) {
			WebElement row = driver.findElement(By
					.xpath("//table[@id='calendar_view_event']/tbody/tr[" + i
							+ "]/td[1]"));
			// Se o label for encontrado entao pega o valor encontrado na
			// segunda coluna da tabela.
			if (label.equals(row.getText())) {
				return driver.findElement(
						By.xpath("//table[@id='calendar_view_event']/tbody/tr["
								+ i + "]/td[2]")).getText();
			}
		}
		return null;
	}
}
